package conecta4;

import java.util.*;
import java.util.Timer;
import javax.swing.*;


import conecta4.tablero.Posicion;
import conecta4.tablero.Valor;
import window.*;
import window.MainFrame.ColorSelection;
import window.MainFrame.PlayerSelection;
import window.graficos.ControlGrafico;


public class ControlJuego extends TimerTask {
	private int tick;
	private MainFrame frame;
	private Timer timer;
	private ControlEventos controlEventos;
	private ControlGrafico controlGrafico;
	private Posicion posicion;
	private HumanPlayer humanPlayer1, humanPlayer2;

	Player player1, player2, currentPlayer;		// Aliases
	private enum State { CONTROLS, THINKING, TIRAR, ENDGAME, VACIAR }
	private State state;
	private int winsPlayer1, winsPlayer2;
	
	public ControlJuego() {
		// Creamos el frame
		frame = new MainFrame();
		// Un Control de Teclado
		controlEventos = new ControlEventos();
		// Un Control de Grficos
		controlGrafico = new ControlGrafico(frame);
		// Una posicin
		posicion = new Posicion();
		// Tres players, dos humanos y otro AI, al final sin AI
		humanPlayer1 = new HumanPlayer();
		humanPlayer2 = new HumanPlayer();

		winsPlayer1 = winsPlayer2 = 0;
		state = State.CONTROLS;
		// Aplicamos al frame el Control de Eventos y viceversa
		frame.setControlEventos(controlEventos);
		controlEventos.setControlJuego(this);
		// Dibujamos el frame inicial
		controlGrafico.moveAndDraw();
		// Lanzar el timer a FPS (frames/sec). Tiene su propio Thread -> le pasaremos la pelota al EDT
		tick = 0;
		timer = new Timer();
		timer.scheduleAtFixedRate(this, 0, 1000/Constantes.FPS);
	}

	// Este mtodo NO est bajo el control del EDT, sino del hilo del Timer ----
	@Override
	public void run() {
		frame.repaint(); tick++;
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {	nextFrame(); }		// Pasarlo al EDT
		});
	}
	// --------------------------------------------------------------------------
	
	
	void setControlSelection() {
		MainFrame.PlayerSelection ps = frame.getPlayerSelection();
		MainFrame.ColorSelection cs = frame.getColorSelection();
		frame.disableControls();		
		if (state == State.CONTROLS) {
			if (ps == PlayerSelection.VSPLAYER) {
				player1 = humanPlayer1;
				player2 = humanPlayer2;
			}
			if (ps == PlayerSelection.VSCOMPUTER) {
				player1 = humanPlayer1;
				player2 = humanPlayer2;
			}
			if (cs == ColorSelection.YELLOW) {
				Player aux = player1; player1 = player2; player2 = aux;
			}
			controlGrafico.moveAndDraw();
			posicion = new Posicion();
			player1.think(posicion);
			currentPlayer = player1;
			state = State.THINKING;
		}
	}
	
	
	private void nextFrame() {
		int move, fila;
		boolean ok;
		
		if (state == State.THINKING) {
			if (!currentPlayer.isThinking()) {
				move = currentPlayer.getMove();
				ok = posicion.meterFicha(move);
				if (!ok) { currentPlayer.think(posicion); return; };	// Y no podemos hacer ms... ya elegir otro
				fila = posicion.getLastFila();
				controlGrafico.tirarFicha(move, fila, currentPlayer == player1);
				state = State.TIRAR;
			}
		}
		
		if (state == State.TIRAR) {
			controlGrafico.moveAndDraw();
			if (!controlGrafico.isEnMovimiento()) {
				if (posicion.getWinner() == Valor.PLAYER1) {
					winsPlayer1++;
					if (player2 instanceof Player);
				}
				if (posicion.getWinner() == Valor.PLAYER2) {
					winsPlayer2++;
					if (player1 instanceof Player);
				}
				if ((posicion.getWinner() != Valor.NONE) || (posicion.isDraw())) {
					System.out.println("PLAYER1   " + winsPlayer1 + " - " + winsPlayer2 + "   PLAYER2");
					tick = 0;
					state = State.ENDGAME; 
				} else {
					currentPlayer = (currentPlayer == player1 ? player2 : player1);
					currentPlayer.think(posicion);
					state = State.THINKING;
				 }
			}
		}
		
		if (state == State.ENDGAME) {
			if (tick == 3 * Constantes.FPS) {
				controlGrafico.vaciarTablero();
				state = State.VACIAR;
			}
		}
		
		if (state == State.VACIAR) {
			controlGrafico.moveAndDraw();
			if (!controlGrafico.isEnMovimiento()) {
				controlGrafico.retirarFichas();
				frame.enableControls();
				state = State.CONTROLS;
			}
			
		}
	}
	


}
