package conecta4.tablero;

import conecta4.Constantes;

public class EvaluadorPosicion {
	private Posicion posicion;
	
	private enum Direccion {
		HOR(1,0), VER(0,1), DIAG1(1,1), DIAG2(-1,1);
		private int dx,dy;
		
		private Direccion(int dx, int dy) {
			this.dx = dx; this.dy = dy;
		}
		
		public int getDx() { return dx; };
		public int getDy() { return dy; };
	}
	
	
	public EvaluadorPosicion(Posicion posicion) {
		this.posicion = posicion;
	}
	
	
	public Valor getWinner() {
		for (int f = 0; f < Constantes.FILAS_TABLERO; f++) {
			for (int c = 0; c < Constantes.COLUMNAS_TABLERO; c++) {
				if (hay4EnFila(f,c)) {
					return posicion.tablero[f][c];
				}
			}
		}
		return Valor.NONE;
	}
	
	
	public boolean isDraw() {
		// Si no est completo, no hay tablas
		for (int c = 0; c < Constantes.COLUMNAS_TABLERO; c++) {
			if (posicion.tablero[0][c] == Valor.NONE) { return false; };
		}
		// Si hay ganador, aunque est completo, tampoco son tablas
		if (getWinner() != Valor.NONE) { return false; };
		return true;
	}
	
	
	private boolean hay4EnFila(int f, int c, Direccion dir) {
		int dx = dir.getDx();
		int dy = dir.getDy();
		Valor valor = posicion.tablero[f][c];
		// Si el primer valor es de "casilla vacia": no hay
		if (valor == Valor.NONE) { return false; };
		// Barremos los 3 siguientes
		for (int i = 0; i < 3; i++) {
			f += dy; c += dx;
			// Si se sale del tablero: no hay
			if ((f < 0) || (c < 0)) { return false; };
			if ((f == Constantes.FILAS_TABLERO) || (c == Constantes.COLUMNAS_TABLERO)) { return false; };
			// Si no es el mismo valor: no hay
			if (posicion.tablero[f][c] != valor) { return false; };
		}
		// Si pasa todos los tests: OK, 4 en raya
		return true;
	}
	
	
	private boolean hay4EnFila(int f, int c) {
		return (hay4EnFila(f,c,Direccion.HOR) || hay4EnFila(f,c,Direccion.VER) ||
				hay4EnFila(f,c,Direccion.DIAG1) || hay4EnFila(f,c,Direccion.DIAG2)); 
	}

}
