package window;
import java.awt.*;

import javax.swing.*;

import conecta4.Constantes;
import conecta4.ControlEventos;


@SuppressWarnings("serial")
public class MainFrame extends JFrame {
	private static final Point posVersus = new Point(50,10);
	private static final Dimension sizeVersus = new Dimension(200,20);
	private static final Point posColor = new Point(300,10);
	private static final Dimension sizeColor = new Dimension(200,20);
	private static final Point posStart = new Point(550,10);
	private static final Dimension sizeStart = new Dimension(200,20);
	
	MainPanel mainPanel;
	PanelDibujo panelDibujo;
	PanelControl panelControl;
	JComboBox<String> versusCB, colorCB;
	JButton startB;
	
	public enum PlayerSelection { VSPLAYER, VSCOMPUTER }
	public enum ColorSelection { RED, YELLOW }
	
	public MainFrame() {
		super("Conecta 4!");
		// El Frame
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setResizable(false);
		setContentPane(mainPanel = crearMainPanel());
		setSize(new Dimension(new Dimension(Constantes.WIDTH+6,Constantes.HEIGHT+Constantes.HEIGHT_CONTROLS+26)));
		setLocationRelativeTo(null);
		setVisible(true);
		startB.requestFocusInWindow();	// Tras el setVisible!! (si va antes, necesita de pack())
	}
	
	
	public PanelDibujo getPanelDibujo() {
		return panelDibujo;
	}
	
	
	public void setControlEventos(ControlEventos c) {
		startB.addActionListener(c);
		panelDibujo.addKeyListener(c);
	}
	
	
	public PlayerSelection getPlayerSelection() {
		if (versusCB.getSelectedIndex() == 0) { return PlayerSelection.VSPLAYER; };
		return PlayerSelection.VSCOMPUTER;
	}
	
	
	public ColorSelection getColorSelection() {
		if (colorCB.getSelectedIndex() == 0) { return ColorSelection.RED; };
		return ColorSelection.YELLOW;
	}

	
	public void enableControls() {
		versusCB.setEnabled(true);
		colorCB.setEnabled(true);
		startB.setEnabled(true);
	}	
	
	
	public void disableControls() {
		versusCB.setEnabled(false);
		colorCB.setEnabled(false);
		startB.setEnabled(false);
	}
	
	
	private PanelControl crearPanelControl() {
		PanelControl panel = new PanelControl();
		panel.add(versusCB = crearComboBoxVersus());
		panel.add(colorCB = crearComboBoxColor());
		panel.add(startB = crearStartButton());
		return panel;
	}
	
	
	private JComboBox<String> crearComboBoxVersus() {
		String[] s = { "Player vs. Player", "Player vs. Computer" };
		JComboBox<String> cb = new JComboBox<String>(s);
		cb.setSize(sizeVersus);
		cb.setLocation(posVersus);
		return cb;
	}


	private JComboBox<String> crearComboBoxColor() {
		String[] s = { "Player color: RED", "Player color: YELLOW" };
		JComboBox<String> cb = new JComboBox<String>(s);
		cb.setSize(sizeColor);
		cb.setLocation(posColor);
		return cb;
	}
	
	
	private JButton crearStartButton() {
		JButton button = new JButton("PLAY!");
		button.setSize(sizeStart);
		button.setLocation(posStart);
		return button;
	}
	
	
	private PanelDibujo crearPanelDibujo() {
		return new PanelDibujo();
	}
	
	
	private MainPanel crearMainPanel() {
		MainPanel panel = new MainPanel();
		panel.add(panelControl = crearPanelControl());
		panel.add(panelDibujo = crearPanelDibujo());
		return panel;
	}
	

}
