package window.graficos;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.image.BufferedImage;

import window.MainFrame;

import conecta4.Constantes;

public class ControlGrafico {
	private Tablero tablero;
	private Numeros numeros;
	private Ficha[] fichasPlayer1, fichasPlayer2, fichas;	// "fichas" es un alias con las de ambos jugadores
	private BufferedImage buffer;	// Alias
	
	public ControlGrafico(MainFrame frame) {
		buffer = frame.getPanelDibujo().getImage();
		tablero = new Tablero(20,80);
		numeros = new Numeros(62,60);
		fichasPlayer1 = new Ficha[Constantes.NUM_FICHAS_JUGADOR];
		fichasPlayer2 = new Ficha[Constantes.NUM_FICHAS_JUGADOR];
		fichas = new Ficha[Constantes.NUM_FICHAS];
		int j = 0;
		for (int i = 0; i < Constantes.NUM_FICHAS_JUGADOR; i++) {		
			fichasPlayer1[i] = new Ficha(Color.red);
			fichasPlayer2[i] = new Ficha(Color.yellow);
			fichas[j++] = fichasPlayer1[i];
			fichas[j++] = fichasPlayer2[i];
		}
	}
	
	
	public void moveAndDraw() {
		Graphics g = buffer.getGraphics();
		// Movemos los elementos mviles
		for (Ficha f:fichas) { f.mover(); }
		// Dibujamos el fondo
		g.setColor(new Color(0,0,0));
		g.fillRect(0, 0, Constantes.WIDTH, Constantes.HEIGHT);
		// Dibujamos los nmeros
		numeros.draw(g);
		// Dibujamos las fichas
		for (Ficha f:fichas) { f.draw(g); }		
		// Dibujamos el tablero
		tablero.draw(g);
	}
	
	
	public void tirarFicha(int col, int filaDest, boolean player1) {
		Ficha ficha = null;
		Ficha[] fichasPlayer = (player1 ? fichasPlayer1 : fichasPlayer2);
		// Color de los nmeros
		numeros.setSelectedMove(col, player1);
		// Buscamos una ficha libre para tirar
		for (Ficha f:fichasPlayer) { if (!f.isVisible()) { ficha = f; break; }; };
		// Calculamos coordenadas
		int x = tablero.getXCol(col);
		int y0 = tablero.getYStart();
		int y1 = tablero.getYFila(filaDest);
		// Tiramos la ficha
		ficha.caer(x, y0, y1);
	}
	
	
	public void vaciarTablero() {
		numeros.setSelectedMove(-1, true);
		for (Ficha f:fichas) {
			if (f.isVisible()) {
				// Calculamos coordenadas
				int x = f.getX();
				int y0 = f.getY();
				int y1 = tablero.getYFila(Constantes.FILAS_TABLERO) + Constantes.DIAMETRO_FICHA;
				// Tiramos la ficha
				f.caer(x, y0, y1);					
			}
		}
	}
	
	
	public void retirarFichas() {
		for (Ficha f:fichas) { f.desaparece(); };
	}
	
	
	public boolean isEnMovimiento() {
		for (Ficha f:fichas) { if (f.isEnMovimiento()) { return true; }; };
		return false;
	}
	
}
