package window.graficos;

import java.awt.*;
import java.awt.image.BufferedImage;

import conecta4.Constantes;

public class Tablero {
	private static final int DIAMETER = Constantes.DIAMETRO_FICHA - 10;
	private static final int BORDE = 10;
	private static final int HEIGHT = Constantes.FILAS_TABLERO*Constantes.DIAMETRO_FICHA+2*BORDE;
	private static final int WIDTH = Constantes.COLUMNAS_TABLERO*Constantes.DIAMETRO_FICHA+2*BORDE;
	private static final int OFFSET = (Constantes.DIAMETRO_FICHA - DIAMETER) / 2 + BORDE;
	private int offsetX, offsetY;
	private BufferedImage image;
	private Color bkgColor;
	
	public Tablero(int offsetX, int offsetY) {
		this.offsetX = offsetX; this.offsetY = offsetY;
		
		// Creamos la imagen
		image = new BufferedImage(WIDTH, HEIGHT, BufferedImage.TYPE_INT_ARGB);
		Graphics g = image.getGraphics();
		
		// Pintamos un rectngulo azul, al que le "quitaremos" los agujeros redondos
		g.setColor(new Color(50,50,255));
		g.fillRect(0, 0, WIDTH, HEIGHT);
		
		// Pintamos los 42 agujeros en negro
		g.setColor(bkgColor = new Color(0,0,0));
		for (int i = 0; i < Constantes.FILAS_TABLERO; i++) {		
			for (int j = 0; j < Constantes.COLUMNAS_TABLERO; j++) {
				g.fillOval(Constantes.DIAMETRO_FICHA*j+OFFSET, Constantes.DIAMETRO_FICHA*i+OFFSET, DIAMETER, DIAMETER);
			}
		}
		
		// Damos transparencia a los pixels negros
		int transparentColor = bkgColor.getRGB();
		for (int y = 0; y < HEIGHT; y++) {
			for (int x = 0; x < WIDTH; x++) {
				int rgb = image.getRGB(x, y);
				if (rgb == transparentColor) {
					image.setRGB(x, y, rgb & 0x00FFFFFF);
				}
			}
		}
	}
	
	
	public void draw(Graphics g) {
		g.drawImage(image, offsetX, offsetY, WIDTH, HEIGHT, null);
	}
	
	
	public int getXCol(int col) {
		return offsetX + BORDE + Constantes.DIAMETRO_FICHA * col;
	}
	
	
	public int getYStart() {
		return offsetY - Constantes.DIAMETRO_FICHA;
	}
	
	
	public int getYFila(int fila) {
		return offsetY + BORDE + Constantes.DIAMETRO_FICHA * fila;
	}
}

